#!/bin/sh
BASEFOLDER="/var/CommuniGate"
APPLICATION="/opt"
RCDIR="/etc/rc.d"
STARTSCRIPTS="/etc/rc.d/init.d"

more <<!EOF
#
# CommuniGate  This shell script installs
#              the CommuniGate Pro server
#
# Generic Linux version
#
# (c) 1998-2007 Stalker Software, Inc.
#
# This script:
# 1. copies the application folder (with the Server executable and
#    Web Interface html files)
# 2. creates the CommuniGate Base directory and opens it for the
#    mail administrators (the users in the "mail" group).
# 3. Composes the Start/Stop script.
# 4. Places the symbolic links to the Start/Stop script into rcN.d directories
#
# This script does NOT clean your /etc/inetd.conf file:
#    If your system was running any POP, IMAP, poppwd or smtp server started
#    using the /etc/inetd.conf file, clean that file yourself
#
# The script does NOT remove any other file from your rcN.d directories
#    If your system was running any POP, IMAP, poppwd or smtp server (such as
#    sendmail) started with rcN.d scripts, remove those scripts to prevent
#    those other servers from starting.
!EOF
echo -n ">"; read answer

more <<!EOF
#
#
# The the CommuniGate Pro application directory is "${APPLICATION}"
#    If you want to place the application code into a different directory,
#    change the "APPLICATION" variable in this script.
#
# The CommuniGate Pro "base directory" (th folder containing mail accounts,
# settings, logs, etc.) is "$BASEFOLDER"
# 
# The startup script location is "${STARTSCRIPTS}".
# The directory with run-level script directories (rcN.d) is "${RCDIR}"
#
!EOF

echo -n "Continue? [Y]"
read answer 

if [ "N$answer" != "N" ] && [ "$answer" != "Y" ] && [ "$answer" != "y" ]; then
 exit 1
fi

if [ ! -d ${BASEFOLDER} ]; then
  echo "Creating the CommuniGate Base directory..."
  if mkdir -p ${BASEFOLDER}; then
    echo ${BASEFOLDER} " created"
  else
    echo "Failed to create " ${BASEFOLDER} ; exit 1
  fi
  
  if chgrp mail ${BASEFOLDER}; then
    echo "access to ${BASEFOLDER} has been opened for the 'mail' group"
  else
    echo "Failed to open ${BASEFOLDER} for the 'mail' user group"
    exit 1
  fi

  if chmod 2770 ${BASEFOLDER} ; then
    echo "Mode changed for ${BASEFOLDER}"
  else
    echo "Failed to change mode for ${BASEFOLDER}"; exit 1
  fi
fi

echo ""
echo "Copying the CommuniGate Pro application folder"
mkdir -p ${APPLICATION}
if cp -Rf CommuniGate ${APPLICATION}/ ; then
  echo "Application folder has been copied to " ${APPLICATION}
else
  echo "Failed to copy the CommuniGate application folder to " ${APPLICATION}
  exit 1
fi

if chgrp -R mail ${APPLICATION}/CommuniGate ; then
  echo "CommuniGate application is set to group mail"
else
  echo "Failed to assign the group mail to the application files"; exit 1
fi

if chmod 2555 ${APPLICATION}/CommuniGate/CGServer* ; then
  echo "CGServer is set to setguid mode"
else
  echo "failed to set the setguid mode for the CGServer program"; exit 1
fi

if chmod 2555 ${APPLICATION}/CommuniGate/mail ; then
  echo "mail is set to setguid mode"
else
  echo "failed to set the setguid mode for the new mail program"; exit 1
fi

if chmod 2555 ${APPLICATION}/CommuniGate/sendmail ; then
  echo "sendmail is set to setguid mode"
else
  echo "failed to set the setguid mode for the new sendmail program"; exit 1
fi

echo ""
echo "Installing the start-up launcher..."
cat >${STARTSCRIPTS}/CommuniGate <<!EOF
#!/bin/sh
#
# CommuniGate  This shell script takes care of starting and stopping
#              the CommuniGate Pro server
#
# Linux version
#
# chkconfig: 2345 80 30
# description: CommuniGate Pro Communication Server
#
# (c) 1998-2007, Stalker Software, Inc.
#
# The default location for the CommuniGate Pro application folder is
#    ${APPLICATION}
# If you have placed the application folder in a different directory,
#    change the APPLICATION variable
#
# The default location for the CommuniGate Pro "base directory" (a folder
# containing accounts, settings, logs, etc.) is
#   ${BASEFOLDER} 
# If you want to use a different location, change the BASEFOLDER variable
#
#
APPLICATION=${APPLICATION}
BASEFOLDER=${BASEFOLDER}
SUPPLPARAMS=

[ -f \${APPLICATION}/CommuniGate/CGServer ] || exit 0

umask 0
ulimit -u 2000

# Custom startup parameters
if [ -f \${BASEFOLDER}/Startup.sh ]; then
  . \${BASEFOLDER}/Startup.sh
fi

case "\$1" in
  start)
     echo -n "Starting CommuniGate Pro"
     \${APPLICATION}/CommuniGate/CGServer \\
        --Base \${BASEFOLDER} --Daemon \${SUPPLPARAMS} \\
#       --ClusterMember
#       --ClusterFrontend

     ;;
  controller)
    echo "Starting CommuniGate Pro Cluster Controller"
    \${APPLICATION}/CommuniGate/CGServer \\
        --Base \${BASEFOLDER} --Daemon \${SUPPLPARAMS} \\
        --ClusterController
    ;;
  stop)
     if [ -f \${BASEFOLDER}/ProcessID ]; then
       echo "Shutting down the CommuniGate Pro Server"
       kill \`cat \${BASEFOLDER}/ProcessID\`
       sleep 5
     else
       echo "It looks like the CommuniGate Pro Server is not running"
     fi
     ;;
  *)
     echo "Usage: \$0 [ start | controller | stop ]"
     exit 1
esac

exit 0

!EOF

chmod 0775 ${STARTSCRIPTS}/CommuniGate

if [ -f /bin/mail ]; then
  if [ ! -f /bin/LegacyMail ]; then
    echo "renaming /bin/mail->/bin/LegacyMail"
    if ! mv /bin/mail /bin/LegacyMail ; then
      echo "failed to rename the /bin/mail program"; exit 1
    fi
  fi
fi

echo "creating a link for the new /bin/mail program"
if ! ln -s ${APPLICATION}/CommuniGate/mail /bin/mail ; then
  echo "failed to create a link for /bin/mail program" ; exit 1
fi

if ! [ -e ${RCDIR}/rc2.d/K10CommuniGate ]; then
  echo "creating startup script links"
  (cd ${RCDIR}/rc0.d; ln -s ${STARTSCRIPTS}/CommuniGate K10CommuniGate)
  (cd ${RCDIR}/rc1.d; ln -s ${STARTSCRIPTS}/CommuniGate K10CommuniGate)
  (cd ${RCDIR}/rc2.d; ln -s ${STARTSCRIPTS}/CommuniGate K10CommuniGate)
  (cd ${RCDIR}/rc3.d; ln -s ${STARTSCRIPTS}/CommuniGate S80CommuniGate)
  (cd ${RCDIR}/rc5.d; ln -s ${STARTSCRIPTS}/CommuniGate S80CommuniGate)
  (cd ${RCDIR}/rc6.d; ln -s ${STARTSCRIPTS}/CommuniGate K10CommuniGate)
fi

sync

more <<!EOF
# The CommuniGate Pro server has been installed.
#
# Use the Run Level Editor to make the server start automatically
#   when the system starts up
#
# If you are installing the Server for the first time,
#   wait till it starts and look into the
#   ${BASEFOLDER}/Accounts/postmaster.macnt/account.settings
#   file. This file contains the postmaster password.
#
# Connect to the Server using any Web Browser: <http://yourhost:8010>
#   and use the postmaster user name and the postmaster password
#
# Check the General Settings and verify that the Server Main Domain
#   is correct - it should be the FULL domain of your system, i.e.
#   it should be "department.company.com", but not just "department".
#
# Then proceed with registering users.
#
# See <http://www.communigate.com/CommuniGatePro/> for the details.
!EOF
